# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_stats_msg import V0042StatsMsg


class TestV0042StatsMsg(unittest.TestCase):
    """V0042StatsMsg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042StatsMsg:
        """Test V0042StatsMsg
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042StatsMsg`
        """
        model = V0042StatsMsg()
        if include_optional:
            return V0042StatsMsg(
                parts_packed = 56,
                req_time = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                req_time_start = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                server_thread_count = 56,
                agent_queue_size = 56,
                agent_count = 56,
                agent_thread_count = 56,
                dbd_agent_queue_size = 56,
                gettimeofday_latency = 56,
                schedule_cycle_max = 56,
                schedule_cycle_last = 56,
                schedule_cycle_sum = 56,
                schedule_cycle_total = 56,
                schedule_cycle_mean = 56,
                schedule_cycle_mean_depth = 56,
                schedule_cycle_per_minute = 56,
                schedule_cycle_depth = 56,
                schedule_exit = slurmrestpy.models.v0/0/42_schedule_exit_fields.v0.0.42_schedule_exit_fields(
                    end_job_queue = 56,
                    default_queue_depth = 56,
                    max_job_start = 56,
                    max_rpc_cnt = 56,
                    max_sched_time = 56,
                    licenses = 56, ),
                schedule_queue_length = 56,
                jobs_submitted = 56,
                jobs_started = 56,
                jobs_completed = 56,
                jobs_canceled = 56,
                jobs_failed = 56,
                jobs_pending = 56,
                jobs_running = 56,
                job_states_ts = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                bf_backfilled_jobs = 56,
                bf_last_backfilled_jobs = 56,
                bf_backfilled_het_jobs = 56,
                bf_cycle_counter = 56,
                bf_cycle_mean = 56,
                bf_depth_mean = 56,
                bf_depth_mean_try = 56,
                bf_cycle_sum = 56,
                bf_cycle_last = 56,
                bf_cycle_max = 56,
                bf_exit = slurmrestpy.models.v0/0/42_bf_exit_fields.v0.0.42_bf_exit_fields(
                    end_job_queue = 56,
                    bf_max_job_start = 56,
                    bf_max_job_test = 56,
                    bf_max_time = 56,
                    bf_node_space_size = 56,
                    state_changed = 56, ),
                bf_last_depth = 56,
                bf_last_depth_try = 56,
                bf_depth_sum = 56,
                bf_depth_try_sum = 56,
                bf_queue_len = 56,
                bf_queue_len_mean = 56,
                bf_queue_len_sum = 56,
                bf_table_size = 56,
                bf_table_size_sum = 56,
                bf_table_size_mean = 56,
                bf_when_last_cycle = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                bf_active = True,
                rpcs_by_message_type = [
                    slurmrestpy.models.v0/0/42_stats_msg_rpc_type.v0.0.42_stats_msg_rpc_type(
                        type_id = 56,
                        message_type = '',
                        count = 56,
                        queued = 56,
                        dropped = 56,
                        cycle_last = 56,
                        cycle_max = 56,
                        total_time = 56,
                        average_time = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                rpcs_by_user = [
                    slurmrestpy.models.v0/0/42_stats_msg_rpc_user.v0.0.42_stats_msg_rpc_user(
                        user_id = 56,
                        user = '',
                        count = 56,
                        total_time = 56,
                        average_time = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 56, ), )
                    ],
                pending_rpcs = [
                    slurmrestpy.models.v0/0/42_stats_msg_rpc_queue.v0.0.42_stats_msg_rpc_queue(
                        type_id = 56,
                        message_type = '',
                        count = 56, )
                    ],
                pending_rpcs_by_hostlist = [
                    slurmrestpy.models.v0/0/42_stats_msg_rpc_dump.v0.0.42_stats_msg_rpc_dump(
                        type_id = 56,
                        message_type = '',
                        count = [
                            ''
                            ], )
                    ]
            )
        else:
            return V0042StatsMsg(
        )
        """

    def testV0042StatsMsg(self):
        """Test V0042StatsMsg"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing_extensions import Self

from slurmrestpy.models.v0042_kill_jobs_resp_job_error import V0042KillJobsRespJobError
from slurmrestpy.models.v0042_kill_jobs_resp_job_federation import (
    V0042KillJobsRespJobFederation,
)
from slurmrestpy.models.v0042_uint32_no_val_struct import V0042Uint32NoValStruct


class V0042KillJobsRespJob(BaseModel):
    """
    V0042KillJobsRespJob
    """  # noqa: E501

    error: Optional[V0042KillJobsRespJobError] = None
    step_id: StrictStr = Field(description="Job or Step ID that signaling failed")
    job_id: V0042Uint32NoValStruct
    federation: Optional[V0042KillJobsRespJobFederation] = None
    __properties: ClassVar[List[str]] = ["error", "step_id", "job_id", "federation"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0042KillJobsRespJob from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of error
        if self.error:
            _dict["error"] = self.error.to_dict()
        # override the default output from pydantic by calling `to_dict()` of job_id
        if self.job_id:
            _dict["job_id"] = self.job_id.to_dict()
        # override the default output from pydantic by calling `to_dict()` of federation
        if self.federation:
            _dict["federation"] = self.federation.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0042KillJobsRespJob from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "error": V0042KillJobsRespJobError.from_dict(obj["error"])
                if obj.get("error") is not None
                else None,
                "step_id": obj.get("step_id"),
                "job_id": V0042Uint32NoValStruct.from_dict(obj["job_id"])
                if obj.get("job_id") is not None
                else None,
                "federation": V0042KillJobsRespJobFederation.from_dict(
                    obj["federation"]
                )
                if obj.get("federation") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_nodes_resp import V0041OpenapiNodesResp


class TestV0041OpenapiNodesResp(unittest.TestCase):
    """V0041OpenapiNodesResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiNodesResp:
        """Test V0041OpenapiNodesResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiNodesResp`
        """
        model = V0041OpenapiNodesResp()
        if include_optional:
            return V0041OpenapiNodesResp(
                nodes = [
                    slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner.v0_0_41_openapi_nodes_resp_nodes_inner(
                        architecture = '',
                        burstbuffer_network_address = '',
                        boards = 56,
                        boot_time = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_boot_time.v0_0_41_openapi_nodes_resp_nodes_inner_boot_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cluster_name = '',
                        cores = 56,
                        specialized_cores = 56,
                        cpu_binding = 56,
                        cpu_load = 56,
                        free_mem = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_free_mem.v0_0_41_openapi_nodes_resp_nodes_inner_free_mem(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus = 56,
                        effective_cpus = 56,
                        specialized_cpus = '',
                        energy = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_energy.v0_0_41_openapi_nodes_resp_nodes_inner_energy(
                            average_watts = 56,
                            base_consumed_energy = 56,
                            consumed_energy = 56,
                            current_watts = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_energy_current_watts.v0_0_41_openapi_nodes_resp_nodes_inner_energy_current_watts(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            previous_consumed_energy = 56,
                            last_collected = 56, ),
                        external_sensors = slurmrestpy.models.external_sensors.external_sensors(),
                        extra = '',
                        power = slurmrestpy.models.power.power(),
                        features = [
                            ''
                            ],
                        active_features = [
                            ''
                            ],
                        gpu_spec = '',
                        gres = '',
                        gres_drained = '',
                        gres_used = '',
                        instance_id = '',
                        instance_type = '',
                        last_busy = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_last_busy.v0_0_41_openapi_nodes_resp_nodes_inner_last_busy(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        mcs_label = '',
                        specialized_memory = 56,
                        name = '',
                        next_state_after_reboot = [
                            'INVALID'
                            ],
                        address = '',
                        hostname = '',
                        state = [
                            'INVALID'
                            ],
                        operating_system = '',
                        owner = '',
                        partitions = [
                            ''
                            ],
                        port = 56,
                        real_memory = 56,
                        res_cores_per_gpu = 56,
                        comment = '',
                        reason = '',
                        reason_changed_at = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_reason_changed_at.v0_0_41_openapi_nodes_resp_nodes_inner_reason_changed_at(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        reason_set_by_user = '',
                        resume_after = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_resume_after.v0_0_41_openapi_nodes_resp_nodes_inner_resume_after(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        reservation = '',
                        alloc_memory = 56,
                        alloc_cpus = 56,
                        alloc_idle_cpus = 56,
                        tres_used = '',
                        tres_weighted = 1.337,
                        slurmd_start_time = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_slurmd_start_time.v0_0_41_openapi_nodes_resp_nodes_inner_slurmd_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        sockets = 56,
                        threads = 56,
                        temporary_disk = 56,
                        weight = 56,
                        tres = '',
                        version = '', )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_nodes_resp_last_update.v0_0_41_openapi_nodes_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
                meta = slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_meta.v0_0_41_openapi_slurmdbd_jobs_resp_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner.v0_0_41_openapi_slurmdbd_jobs_resp_errors_inner(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner.v0_0_41_openapi_slurmdbd_jobs_resp_warnings_inner(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0041OpenapiNodesResp(
                nodes = [
                    slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner.v0_0_41_openapi_nodes_resp_nodes_inner(
                        architecture = '',
                        burstbuffer_network_address = '',
                        boards = 56,
                        boot_time = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_boot_time.v0_0_41_openapi_nodes_resp_nodes_inner_boot_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cluster_name = '',
                        cores = 56,
                        specialized_cores = 56,
                        cpu_binding = 56,
                        cpu_load = 56,
                        free_mem = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_free_mem.v0_0_41_openapi_nodes_resp_nodes_inner_free_mem(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        cpus = 56,
                        effective_cpus = 56,
                        specialized_cpus = '',
                        energy = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_energy.v0_0_41_openapi_nodes_resp_nodes_inner_energy(
                            average_watts = 56,
                            base_consumed_energy = 56,
                            consumed_energy = 56,
                            current_watts = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_energy_current_watts.v0_0_41_openapi_nodes_resp_nodes_inner_energy_current_watts(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            previous_consumed_energy = 56,
                            last_collected = 56, ),
                        external_sensors = slurmrestpy.models.external_sensors.external_sensors(),
                        extra = '',
                        power = slurmrestpy.models.power.power(),
                        features = [
                            ''
                            ],
                        active_features = [
                            ''
                            ],
                        gpu_spec = '',
                        gres = '',
                        gres_drained = '',
                        gres_used = '',
                        instance_id = '',
                        instance_type = '',
                        last_busy = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_last_busy.v0_0_41_openapi_nodes_resp_nodes_inner_last_busy(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        mcs_label = '',
                        specialized_memory = 56,
                        name = '',
                        next_state_after_reboot = [
                            'INVALID'
                            ],
                        address = '',
                        hostname = '',
                        state = [
                            'INVALID'
                            ],
                        operating_system = '',
                        owner = '',
                        partitions = [
                            ''
                            ],
                        port = 56,
                        real_memory = 56,
                        res_cores_per_gpu = 56,
                        comment = '',
                        reason = '',
                        reason_changed_at = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_reason_changed_at.v0_0_41_openapi_nodes_resp_nodes_inner_reason_changed_at(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        reason_set_by_user = '',
                        resume_after = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_resume_after.v0_0_41_openapi_nodes_resp_nodes_inner_resume_after(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        reservation = '',
                        alloc_memory = 56,
                        alloc_cpus = 56,
                        alloc_idle_cpus = 56,
                        tres_used = '',
                        tres_weighted = 1.337,
                        slurmd_start_time = slurmrestpy.models.v0_0_41_openapi_nodes_resp_nodes_inner_slurmd_start_time.v0_0_41_openapi_nodes_resp_nodes_inner_slurmd_start_time(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        sockets = 56,
                        threads = 56,
                        temporary_disk = 56,
                        weight = 56,
                        tres = '',
                        version = '', )
                    ],
                last_update = slurmrestpy.models.v0_0_41_openapi_nodes_resp_last_update.v0_0_41_openapi_nodes_resp_last_update(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0041OpenapiNodesResp(self):
        """Test V0041OpenapiNodesResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_shares_resp_msg import V0042SharesRespMsg


class TestV0042SharesRespMsg(unittest.TestCase):
    """V0042SharesRespMsg unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042SharesRespMsg:
        """Test V0042SharesRespMsg
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042SharesRespMsg`
        """
        model = V0042SharesRespMsg()
        if include_optional:
            return V0042SharesRespMsg(
                shares = [
                    slurmrestpy.models.v0/0/42_assoc_shares_obj_wrap.v0.0.42_assoc_shares_obj_wrap(
                        id = 56,
                        cluster = '',
                        name = '',
                        parent = '',
                        partition = '',
                        shares_normalized = slurmrestpy.models.v0/0/42_float64_no_val_struct.v0.0.42_float64_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        shares = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 56, ),
                        tres = slurmrestpy.models.v0_0_42_assoc_shares_obj_wrap_tres.v0_0_42_assoc_shares_obj_wrap_tres(
                            run_seconds = [
                                slurmrestpy.models.v0/0/42_shares_uint64_tres.v0.0.42_shares_uint64_tres(
                                    name = '',
                                    value = slurmrestpy.models.v0/0/42_uint64_no_val_struct.v0.0.42_uint64_no_val_struct(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), )
                                ],
                            group_minutes = [
                                slurmrestpy.models.v0/0/42_shares_uint64_tres.v0.0.42_shares_uint64_tres(
                                    name = '', )
                                ],
                            usage = [
                                slurmrestpy.models.v0/0/42_shares_float128_tres.v0.0.42_shares_float128_tres(
                                    name = '', )
                                ], ),
                        effective_usage = slurmrestpy.models.v0/0/42_float64_no_val_struct.v0.0.42_float64_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_normalized = ,
                        usage = 56,
                        fairshare = slurmrestpy.models.v0_0_42_assoc_shares_obj_wrap_fairshare.v0_0_42_assoc_shares_obj_wrap_fairshare(
                            factor = ,
                            level = , ),
                        type = [
                            'USER'
                            ], )
                    ],
                total_shares = 56
            )
        else:
            return V0042SharesRespMsg(
        )
        """

    def testV0042SharesRespMsg(self):
        """Test V0042SharesRespMsg"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

__version__ = "1.0.0"

# import apis into sdk package
from slurmrestpy.api.slurm_api import SlurmApi
from slurmrestpy.api.slurmdb_api import SlurmdbApi

# import ApiClient
from slurmrestpy.api_response import ApiResponse
from slurmrestpy.api_client import ApiClient
from slurmrestpy.configuration import Configuration
from slurmrestpy.exceptions import OpenApiException
from slurmrestpy.exceptions import ApiTypeError
from slurmrestpy.exceptions import ApiValueError
from slurmrestpy.exceptions import ApiKeyError
from slurmrestpy.exceptions import ApiAttributeError
from slurmrestpy.exceptions import ApiException

# import models into sdk package
from slurmrestpy.models.v0040_account import V0040Account
from slurmrestpy.models.v0040_account_short import V0040AccountShort
from slurmrestpy.models.v0040_accounting import V0040Accounting
from slurmrestpy.models.v0040_accounting_allocated import V0040AccountingAllocated
from slurmrestpy.models.v0040_accounts_add_cond import V0040AccountsAddCond
from slurmrestpy.models.v0040_acct_gather_energy import V0040AcctGatherEnergy
from slurmrestpy.models.v0040_assoc import V0040Assoc
from slurmrestpy.models.v0040_assoc_max import V0040AssocMax
from slurmrestpy.models.v0040_assoc_max_jobs import V0040AssocMaxJobs
from slurmrestpy.models.v0040_assoc_max_jobs_per import V0040AssocMaxJobsPer
from slurmrestpy.models.v0040_assoc_max_per import V0040AssocMaxPer
from slurmrestpy.models.v0040_assoc_max_per_account import V0040AssocMaxPerAccount
from slurmrestpy.models.v0040_assoc_max_tres import V0040AssocMaxTres
from slurmrestpy.models.v0040_assoc_max_tres_group import V0040AssocMaxTresGroup
from slurmrestpy.models.v0040_assoc_max_tres_minutes import V0040AssocMaxTresMinutes
from slurmrestpy.models.v0040_assoc_max_tres_per import V0040AssocMaxTresPer
from slurmrestpy.models.v0040_assoc_min import V0040AssocMin
from slurmrestpy.models.v0040_assoc_rec_set import V0040AssocRecSet
from slurmrestpy.models.v0040_assoc_shares_obj_wrap import V0040AssocSharesObjWrap
from slurmrestpy.models.v0040_assoc_shares_obj_wrap_fairshare import (
    V0040AssocSharesObjWrapFairshare,
)
from slurmrestpy.models.v0040_assoc_shares_obj_wrap_tres import (
    V0040AssocSharesObjWrapTres,
)
from slurmrestpy.models.v0040_assoc_short import V0040AssocShort
from slurmrestpy.models.v0040_bf_exit_fields import V0040BfExitFields
from slurmrestpy.models.v0040_cluster_rec import V0040ClusterRec
from slurmrestpy.models.v0040_cluster_rec_associations import (
    V0040ClusterRecAssociations,
)
from slurmrestpy.models.v0040_controller_ping import V0040ControllerPing
from slurmrestpy.models.v0040_coord import V0040Coord
from slurmrestpy.models.v0040_cron_entry import V0040CronEntry
from slurmrestpy.models.v0040_float64_no_val import V0040Float64NoVal
from slurmrestpy.models.v0040_instance import V0040Instance
from slurmrestpy.models.v0040_job import V0040Job
from slurmrestpy.models.v0040_job_array import V0040JobArray
from slurmrestpy.models.v0040_job_array_response_msg_entry import (
    V0040JobArrayResponseMsgEntry,
)
from slurmrestpy.models.v0040_job_desc_msg import V0040JobDescMsg
from slurmrestpy.models.v0040_job_desc_msg_rlimits import V0040JobDescMsgRlimits
from slurmrestpy.models.v0040_job_het import V0040JobHet
from slurmrestpy.models.v0040_job_info import V0040JobInfo
from slurmrestpy.models.v0040_job_info_power import V0040JobInfoPower
from slurmrestpy.models.v0040_job_required import V0040JobRequired
from slurmrestpy.models.v0040_job_res import V0040JobRes
from slurmrestpy.models.v0040_job_state import V0040JobState
from slurmrestpy.models.v0040_job_submit_req import V0040JobSubmitReq
from slurmrestpy.models.v0040_job_submit_response_msg import V0040JobSubmitResponseMsg
from slurmrestpy.models.v0040_job_time import V0040JobTime
from slurmrestpy.models.v0040_job_tres import V0040JobTres
from slurmrestpy.models.v0040_kill_jobs_msg import V0040KillJobsMsg
from slurmrestpy.models.v0040_kill_jobs_resp_job import V0040KillJobsRespJob
from slurmrestpy.models.v0040_license import V0040License
from slurmrestpy.models.v0040_node import V0040Node
from slurmrestpy.models.v0040_openapi_accounts_add_cond_resp import (
    V0040OpenapiAccountsAddCondResp,
)
from slurmrestpy.models.v0040_openapi_accounts_add_cond_resp_str import (
    V0040OpenapiAccountsAddCondRespStr,
)
from slurmrestpy.models.v0040_openapi_accounts_removed_resp import (
    V0040OpenapiAccountsRemovedResp,
)
from slurmrestpy.models.v0040_openapi_accounts_resp import V0040OpenapiAccountsResp
from slurmrestpy.models.v0040_openapi_assocs_removed_resp import (
    V0040OpenapiAssocsRemovedResp,
)
from slurmrestpy.models.v0040_openapi_assocs_resp import V0040OpenapiAssocsResp
from slurmrestpy.models.v0040_openapi_clusters_removed_resp import (
    V0040OpenapiClustersRemovedResp,
)
from slurmrestpy.models.v0040_openapi_clusters_resp import V0040OpenapiClustersResp
from slurmrestpy.models.v0040_openapi_diag_resp import V0040OpenapiDiagResp
from slurmrestpy.models.v0040_openapi_error import V0040OpenapiError
from slurmrestpy.models.v0040_openapi_instances_resp import V0040OpenapiInstancesResp
from slurmrestpy.models.v0040_openapi_job_info_resp import V0040OpenapiJobInfoResp
from slurmrestpy.models.v0040_openapi_job_post_response import (
    V0040OpenapiJobPostResponse,
)
from slurmrestpy.models.v0040_openapi_job_submit_response import (
    V0040OpenapiJobSubmitResponse,
)
from slurmrestpy.models.v0040_openapi_kill_jobs_resp import V0040OpenapiKillJobsResp
from slurmrestpy.models.v0040_openapi_licenses_resp import V0040OpenapiLicensesResp
from slurmrestpy.models.v0040_openapi_meta import V0040OpenapiMeta
from slurmrestpy.models.v0040_openapi_nodes_resp import V0040OpenapiNodesResp
from slurmrestpy.models.v0040_openapi_partition_resp import V0040OpenapiPartitionResp
from slurmrestpy.models.v0040_openapi_ping_array_resp import V0040OpenapiPingArrayResp
from slurmrestpy.models.v0040_openapi_reservation_resp import (
    V0040OpenapiReservationResp,
)
from slurmrestpy.models.v0040_openapi_resp import V0040OpenapiResp
from slurmrestpy.models.v0040_openapi_shares_resp import V0040OpenapiSharesResp
from slurmrestpy.models.v0040_openapi_slurmdbd_config_resp import (
    V0040OpenapiSlurmdbdConfigResp,
)
from slurmrestpy.models.v0040_openapi_slurmdbd_jobs_resp import (
    V0040OpenapiSlurmdbdJobsResp,
)
from slurmrestpy.models.v0040_openapi_slurmdbd_qos_removed_resp import (
    V0040OpenapiSlurmdbdQosRemovedResp,
)
from slurmrestpy.models.v0040_openapi_slurmdbd_qos_resp import (
    V0040OpenapiSlurmdbdQosResp,
)
from slurmrestpy.models.v0040_openapi_slurmdbd_stats_resp import (
    V0040OpenapiSlurmdbdStatsResp,
)
from slurmrestpy.models.v0040_openapi_tres_resp import V0040OpenapiTresResp
from slurmrestpy.models.v0040_openapi_users_add_cond_resp import (
    V0040OpenapiUsersAddCondResp,
)
from slurmrestpy.models.v0040_openapi_users_add_cond_resp_str import (
    V0040OpenapiUsersAddCondRespStr,
)
from slurmrestpy.models.v0040_openapi_users_resp import V0040OpenapiUsersResp
from slurmrestpy.models.v0040_openapi_warning import V0040OpenapiWarning
from slurmrestpy.models.v0040_openapi_wckey_removed_resp import (
    V0040OpenapiWckeyRemovedResp,
)
from slurmrestpy.models.v0040_openapi_wckey_resp import V0040OpenapiWckeyResp
from slurmrestpy.models.v0040_partition_info import V0040PartitionInfo
from slurmrestpy.models.v0040_partition_info_defaults import V0040PartitionInfoDefaults
from slurmrestpy.models.v0040_partition_info_maximums import V0040PartitionInfoMaximums
from slurmrestpy.models.v0040_partition_info_maximums_oversubscribe import (
    V0040PartitionInfoMaximumsOversubscribe,
)
from slurmrestpy.models.v0040_partition_info_partition import (
    V0040PartitionInfoPartition,
)
from slurmrestpy.models.v0040_partition_info_timeouts import V0040PartitionInfoTimeouts
from slurmrestpy.models.v0040_process_exit_code_verbose import (
    V0040ProcessExitCodeVerbose,
)
from slurmrestpy.models.v0040_process_exit_code_verbose_signal import (
    V0040ProcessExitCodeVerboseSignal,
)
from slurmrestpy.models.v0040_qos import V0040Qos
from slurmrestpy.models.v0040_qos_limits import V0040QosLimits
from slurmrestpy.models.v0040_qos_limits_max import V0040QosLimitsMax
from slurmrestpy.models.v0040_qos_limits_max_active_jobs import (
    V0040QosLimitsMaxActiveJobs,
)
from slurmrestpy.models.v0040_qos_limits_max_jobs import V0040QosLimitsMaxJobs
from slurmrestpy.models.v0040_qos_limits_max_jobs_active_jobs import (
    V0040QosLimitsMaxJobsActiveJobs,
)
from slurmrestpy.models.v0040_qos_limits_max_jobs_active_jobs_per import (
    V0040QosLimitsMaxJobsActiveJobsPer,
)
from slurmrestpy.models.v0040_qos_limits_max_tres import V0040QosLimitsMaxTres
from slurmrestpy.models.v0040_qos_limits_max_tres_minutes import (
    V0040QosLimitsMaxTresMinutes,
)
from slurmrestpy.models.v0040_qos_limits_max_tres_minutes_per import (
    V0040QosLimitsMaxTresMinutesPer,
)
from slurmrestpy.models.v0040_qos_limits_max_tres_per import V0040QosLimitsMaxTresPer
from slurmrestpy.models.v0040_qos_limits_max_wall_clock import (
    V0040QosLimitsMaxWallClock,
)
from slurmrestpy.models.v0040_qos_limits_max_wall_clock_per import (
    V0040QosLimitsMaxWallClockPer,
)
from slurmrestpy.models.v0040_qos_limits_min import V0040QosLimitsMin
from slurmrestpy.models.v0040_qos_limits_min_tres import V0040QosLimitsMinTres
from slurmrestpy.models.v0040_qos_limits_min_tres_per import V0040QosLimitsMinTresPer
from slurmrestpy.models.v0040_qos_preempt import V0040QosPreempt
from slurmrestpy.models.v0040_reservation_core_spec import V0040ReservationCoreSpec
from slurmrestpy.models.v0040_reservation_info import V0040ReservationInfo
from slurmrestpy.models.v0040_reservation_info_purge_completed import (
    V0040ReservationInfoPurgeCompleted,
)
from slurmrestpy.models.v0040_rollup_stats_inner import V0040RollupStatsInner
from slurmrestpy.models.v0040_schedule_exit_fields import V0040ScheduleExitFields
from slurmrestpy.models.v0040_shares_float128_tres import V0040SharesFloat128Tres
from slurmrestpy.models.v0040_shares_resp_msg import V0040SharesRespMsg
from slurmrestpy.models.v0040_shares_uint64_tres import V0040SharesUint64Tres
from slurmrestpy.models.v0040_stats_msg import V0040StatsMsg
from slurmrestpy.models.v0040_stats_msg_rpcs_by_type_inner import (
    V0040StatsMsgRpcsByTypeInner,
)
from slurmrestpy.models.v0040_stats_msg_rpcs_by_user_inner import (
    V0040StatsMsgRpcsByUserInner,
)
from slurmrestpy.models.v0040_stats_rec import V0040StatsRec
from slurmrestpy.models.v0040_stats_rpc import V0040StatsRpc
from slurmrestpy.models.v0040_stats_user import V0040StatsUser
from slurmrestpy.models.v0040_step import V0040Step
from slurmrestpy.models.v0040_step_cpu import V0040StepCPU
from slurmrestpy.models.v0040_step_cpu_requested_frequency import (
    V0040StepCPURequestedFrequency,
)
from slurmrestpy.models.v0040_step_nodes import V0040StepNodes
from slurmrestpy.models.v0040_step_statistics import V0040StepStatistics
from slurmrestpy.models.v0040_step_statistics_energy import V0040StepStatisticsEnergy
from slurmrestpy.models.v0040_step_step import V0040StepStep
from slurmrestpy.models.v0040_step_time import V0040StepTime
from slurmrestpy.models.v0040_step_tres import V0040StepTres
from slurmrestpy.models.v0040_step_tres_consumed import V0040StepTresConsumed
from slurmrestpy.models.v0040_step_tres_requested import V0040StepTresRequested
from slurmrestpy.models.v0040_tres import V0040Tres
from slurmrestpy.models.v0040_uint16_no_val import V0040Uint16NoVal
from slurmrestpy.models.v0040_uint32_no_val import V0040Uint32NoVal
from slurmrestpy.models.v0040_uint64_no_val import V0040Uint64NoVal
from slurmrestpy.models.v0040_update_node_msg import V0040UpdateNodeMsg
from slurmrestpy.models.v0040_user import V0040User
from slurmrestpy.models.v0040_user_default import V0040UserDefault
from slurmrestpy.models.v0040_user_short import V0040UserShort
from slurmrestpy.models.v0040_users_add_cond import V0040UsersAddCond
from slurmrestpy.models.v0040_wckey import V0040Wckey
from slurmrestpy.models.v0040_wckey_tag_struct import V0040WckeyTagStruct
from slurmrestpy.models.v0041_job_alloc_req import V0041JobAllocReq
from slurmrestpy.models.v0041_job_desc_msg import V0041JobDescMsg
from slurmrestpy.models.v0041_job_desc_msg_begin_time import V0041JobDescMsgBeginTime
from slurmrestpy.models.v0041_job_desc_msg_crontab import V0041JobDescMsgCrontab
from slurmrestpy.models.v0041_job_desc_msg_distribution_plane_size import (
    V0041JobDescMsgDistributionPlaneSize,
)
from slurmrestpy.models.v0041_job_desc_msg_kill_warning_delay import (
    V0041JobDescMsgKillWarningDelay,
)
from slurmrestpy.models.v0041_job_desc_msg_required_switches import (
    V0041JobDescMsgRequiredSwitches,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits import V0041JobDescMsgRlimits
from slurmrestpy.models.v0041_job_desc_msg_rlimits_as import V0041JobDescMsgRlimitsAs
from slurmrestpy.models.v0041_job_desc_msg_rlimits_core import (
    V0041JobDescMsgRlimitsCore,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_cpu import V0041JobDescMsgRlimitsCpu
from slurmrestpy.models.v0041_job_desc_msg_rlimits_data import (
    V0041JobDescMsgRlimitsData,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_fsize import (
    V0041JobDescMsgRlimitsFsize,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_memlock import (
    V0041JobDescMsgRlimitsMemlock,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_nofile import (
    V0041JobDescMsgRlimitsNofile,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_nproc import (
    V0041JobDescMsgRlimitsNproc,
)
from slurmrestpy.models.v0041_job_desc_msg_rlimits_rss import V0041JobDescMsgRlimitsRss
from slurmrestpy.models.v0041_job_desc_msg_rlimits_stack import (
    V0041JobDescMsgRlimitsStack,
)
from slurmrestpy.models.v0041_job_desc_msg_segment_size import (
    V0041JobDescMsgSegmentSize,
)
from slurmrestpy.models.v0041_job_desc_msg_time_minimum import (
    V0041JobDescMsgTimeMinimum,
)
from slurmrestpy.models.v0041_job_submit_req import V0041JobSubmitReq
from slurmrestpy.models.v0041_kill_jobs_msg import V0041KillJobsMsg
from slurmrestpy.models.v0041_openapi_accounts_add_cond_resp import (
    V0041OpenapiAccountsAddCondResp,
)
from slurmrestpy.models.v0041_openapi_accounts_add_cond_resp_account import (
    V0041OpenapiAccountsAddCondRespAccount,
)
from slurmrestpy.models.v0041_openapi_accounts_add_cond_resp_association_condition import (
    V0041OpenapiAccountsAddCondRespAssociationCondition,
)
from slurmrestpy.models.v0041_openapi_accounts_add_cond_resp_str import (
    V0041OpenapiAccountsAddCondRespStr,
)
from slurmrestpy.models.v0041_openapi_accounts_removed_resp import (
    V0041OpenapiAccountsRemovedResp,
)
from slurmrestpy.models.v0041_openapi_accounts_resp import V0041OpenapiAccountsResp
from slurmrestpy.models.v0041_openapi_assocs_removed_resp import (
    V0041OpenapiAssocsRemovedResp,
)
from slurmrestpy.models.v0041_openapi_assocs_resp import V0041OpenapiAssocsResp
from slurmrestpy.models.v0041_openapi_clusters_removed_resp import (
    V0041OpenapiClustersRemovedResp,
)
from slurmrestpy.models.v0041_openapi_clusters_resp import V0041OpenapiClustersResp
from slurmrestpy.models.v0041_openapi_diag_resp import V0041OpenapiDiagResp
from slurmrestpy.models.v0041_openapi_diag_resp_statistics import (
    V0041OpenapiDiagRespStatistics,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_bf_exit import (
    V0041OpenapiDiagRespStatisticsBfExit,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_bf_when_last_cycle import (
    V0041OpenapiDiagRespStatisticsBfWhenLastCycle,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_job_states_ts import (
    V0041OpenapiDiagRespStatisticsJobStatesTs,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_pending_rpcs_by_hostlist_inner import (
    V0041OpenapiDiagRespStatisticsPendingRpcsByHostlistInner,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_pending_rpcs_inner import (
    V0041OpenapiDiagRespStatisticsPendingRpcsInner,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_req_time import (
    V0041OpenapiDiagRespStatisticsReqTime,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_req_time_start import (
    V0041OpenapiDiagRespStatisticsReqTimeStart,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_rpcs_by_message_type_inner import (
    V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInner,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_rpcs_by_message_type_inner_average_time import (
    V0041OpenapiDiagRespStatisticsRpcsByMessageTypeInnerAverageTime,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_rpcs_by_user_inner import (
    V0041OpenapiDiagRespStatisticsRpcsByUserInner,
)
from slurmrestpy.models.v0041_openapi_diag_resp_statistics_schedule_exit import (
    V0041OpenapiDiagRespStatisticsScheduleExit,
)
from slurmrestpy.models.v0041_openapi_instances_resp import V0041OpenapiInstancesResp
from slurmrestpy.models.v0041_openapi_job_alloc_resp import V0041OpenapiJobAllocResp
from slurmrestpy.models.v0041_openapi_job_info_resp import V0041OpenapiJobInfoResp
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner import (
    V0041OpenapiJobInfoRespJobsInner,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_accrue_time import (
    V0041OpenapiJobInfoRespJobsInnerAccrueTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_array_job_id import (
    V0041OpenapiJobInfoRespJobsInnerArrayJobId,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_array_max_tasks import (
    V0041OpenapiJobInfoRespJobsInnerArrayMaxTasks,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_billable_tres import (
    V0041OpenapiJobInfoRespJobsInnerBillableTres,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cores_per_socket import (
    V0041OpenapiJobInfoRespJobsInnerCoresPerSocket,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cpu_frequency_governor import (
    V0041OpenapiJobInfoRespJobsInnerCpuFrequencyGovernor,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cpu_frequency_maximum import (
    V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMaximum,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cpu_frequency_minimum import (
    V0041OpenapiJobInfoRespJobsInnerCpuFrequencyMinimum,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cpus import (
    V0041OpenapiJobInfoRespJobsInnerCpus,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_cpus_per_task import (
    V0041OpenapiJobInfoRespJobsInnerCpusPerTask,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_deadline import (
    V0041OpenapiJobInfoRespJobsInnerDeadline,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_delay_boot import (
    V0041OpenapiJobInfoRespJobsInnerDelayBoot,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_eligible_time import (
    V0041OpenapiJobInfoRespJobsInnerEligibleTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_end_time import (
    V0041OpenapiJobInfoRespJobsInnerEndTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_exit_code import (
    V0041OpenapiJobInfoRespJobsInnerExitCode,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_het_job_id import (
    V0041OpenapiJobInfoRespJobsInnerHetJobId,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources import (
    V0041OpenapiJobInfoRespJobsInnerJobResources,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodes,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInner,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInner,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_nodes_allocation_inner_sockets_inner_cores_inner import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesNodesAllocationInnerSocketsInnerCoresInner,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_job_resources_threads_per_core import (
    V0041OpenapiJobInfoRespJobsInnerJobResourcesThreadsPerCore,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_last_sched_evaluation import (
    V0041OpenapiJobInfoRespJobsInnerLastSchedEvaluation,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_max_cpus import (
    V0041OpenapiJobInfoRespJobsInnerMaxCpus,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_max_nodes import (
    V0041OpenapiJobInfoRespJobsInnerMaxNodes,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_minimum_cpus_per_node import (
    V0041OpenapiJobInfoRespJobsInnerMinimumCpusPerNode,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_minimum_tmp_disk_per_node import (
    V0041OpenapiJobInfoRespJobsInnerMinimumTmpDiskPerNode,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_node_count import (
    V0041OpenapiJobInfoRespJobsInnerNodeCount,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_pre_sus_time import (
    V0041OpenapiJobInfoRespJobsInnerPreSusTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_preempt_time import (
    V0041OpenapiJobInfoRespJobsInnerPreemptTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_preemptable_time import (
    V0041OpenapiJobInfoRespJobsInnerPreemptableTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_resize_time import (
    V0041OpenapiJobInfoRespJobsInnerResizeTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_sockets_per_node import (
    V0041OpenapiJobInfoRespJobsInnerSocketsPerNode,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_start_time import (
    V0041OpenapiJobInfoRespJobsInnerStartTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_submit_time import (
    V0041OpenapiJobInfoRespJobsInnerSubmitTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_suspend_time import (
    V0041OpenapiJobInfoRespJobsInnerSuspendTime,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks import (
    V0041OpenapiJobInfoRespJobsInnerTasks,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks_per_board import (
    V0041OpenapiJobInfoRespJobsInnerTasksPerBoard,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks_per_core import (
    V0041OpenapiJobInfoRespJobsInnerTasksPerCore,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks_per_node import (
    V0041OpenapiJobInfoRespJobsInnerTasksPerNode,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks_per_socket import (
    V0041OpenapiJobInfoRespJobsInnerTasksPerSocket,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_tasks_per_tres import (
    V0041OpenapiJobInfoRespJobsInnerTasksPerTres,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_jobs_inner_threads_per_core import (
    V0041OpenapiJobInfoRespJobsInnerThreadsPerCore,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_last_backfill import (
    V0041OpenapiJobInfoRespLastBackfill,
)
from slurmrestpy.models.v0041_openapi_job_info_resp_last_update import (
    V0041OpenapiJobInfoRespLastUpdate,
)
from slurmrestpy.models.v0041_openapi_job_post_response import (
    V0041OpenapiJobPostResponse,
)
from slurmrestpy.models.v0041_openapi_job_post_response_results_inner import (
    V0041OpenapiJobPostResponseResultsInner,
)
from slurmrestpy.models.v0041_openapi_job_submit_response import (
    V0041OpenapiJobSubmitResponse,
)
from slurmrestpy.models.v0041_openapi_job_submit_response_result import (
    V0041OpenapiJobSubmitResponseResult,
)
from slurmrestpy.models.v0041_openapi_kill_jobs_resp import V0041OpenapiKillJobsResp
from slurmrestpy.models.v0041_openapi_kill_jobs_resp_status_inner import (
    V0041OpenapiKillJobsRespStatusInner,
)
from slurmrestpy.models.v0041_openapi_kill_jobs_resp_status_inner_job_id import (
    V0041OpenapiKillJobsRespStatusInnerJobId,
)
from slurmrestpy.models.v0041_openapi_licenses_resp import V0041OpenapiLicensesResp
from slurmrestpy.models.v0041_openapi_licenses_resp_last_update import (
    V0041OpenapiLicensesRespLastUpdate,
)
from slurmrestpy.models.v0041_openapi_licenses_resp_licenses_inner import (
    V0041OpenapiLicensesRespLicensesInner,
)
from slurmrestpy.models.v0041_openapi_nodes_resp import V0041OpenapiNodesResp
from slurmrestpy.models.v0041_openapi_nodes_resp_last_update import (
    V0041OpenapiNodesRespLastUpdate,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner import (
    V0041OpenapiNodesRespNodesInner,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_boot_time import (
    V0041OpenapiNodesRespNodesInnerBootTime,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_energy import (
    V0041OpenapiNodesRespNodesInnerEnergy,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_energy_current_watts import (
    V0041OpenapiNodesRespNodesInnerEnergyCurrentWatts,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_free_mem import (
    V0041OpenapiNodesRespNodesInnerFreeMem,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_last_busy import (
    V0041OpenapiNodesRespNodesInnerLastBusy,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_reason_changed_at import (
    V0041OpenapiNodesRespNodesInnerReasonChangedAt,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_resume_after import (
    V0041OpenapiNodesRespNodesInnerResumeAfter,
)
from slurmrestpy.models.v0041_openapi_nodes_resp_nodes_inner_slurmd_start_time import (
    V0041OpenapiNodesRespNodesInnerSlurmdStartTime,
)
from slurmrestpy.models.v0041_openapi_partition_resp import V0041OpenapiPartitionResp
from slurmrestpy.models.v0041_openapi_partition_resp_last_update import (
    V0041OpenapiPartitionRespLastUpdate,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner import (
    V0041OpenapiPartitionRespPartitionsInner,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_defaults import (
    V0041OpenapiPartitionRespPartitionsInnerDefaults,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_cpu import (
    V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerCpu,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_defaults_partition_memory_per_node import (
    V0041OpenapiPartitionRespPartitionsInnerDefaultsPartitionMemoryPerNode,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_defaults_time import (
    V0041OpenapiPartitionRespPartitionsInnerDefaultsTime,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums import (
    V0041OpenapiPartitionRespPartitionsInnerMaximums,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_cpus_per_node import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerNode,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_cpus_per_socket import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsCpusPerSocket,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_nodes import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsNodes,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_over_time_limit import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsOverTimeLimit,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_oversubscribe import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsOversubscribe,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_partition_memory_per_cpu import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerCpu,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_partition_memory_per_node import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsPartitionMemoryPerNode,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_maximums_time import (
    V0041OpenapiPartitionRespPartitionsInnerMaximumsTime,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_partition import (
    V0041OpenapiPartitionRespPartitionsInnerPartition,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_suspend_time import (
    V0041OpenapiPartitionRespPartitionsInnerSuspendTime,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_timeouts import (
    V0041OpenapiPartitionRespPartitionsInnerTimeouts,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_timeouts_resume import (
    V0041OpenapiPartitionRespPartitionsInnerTimeoutsResume,
)
from slurmrestpy.models.v0041_openapi_partition_resp_partitions_inner_timeouts_suspend import (
    V0041OpenapiPartitionRespPartitionsInnerTimeoutsSuspend,
)
from slurmrestpy.models.v0041_openapi_ping_array_resp import V0041OpenapiPingArrayResp
from slurmrestpy.models.v0041_openapi_ping_array_resp_pings_inner import (
    V0041OpenapiPingArrayRespPingsInner,
)
from slurmrestpy.models.v0041_openapi_reservation_resp import (
    V0041OpenapiReservationResp,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_last_update import (
    V0041OpenapiReservationRespLastUpdate,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner import (
    V0041OpenapiReservationRespReservationsInner,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_core_specializations_inner import (
    V0041OpenapiReservationRespReservationsInnerCoreSpecializationsInner,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_end_time import (
    V0041OpenapiReservationRespReservationsInnerEndTime,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_purge_completed import (
    V0041OpenapiReservationRespReservationsInnerPurgeCompleted,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_purge_completed_time import (
    V0041OpenapiReservationRespReservationsInnerPurgeCompletedTime,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_start_time import (
    V0041OpenapiReservationRespReservationsInnerStartTime,
)
from slurmrestpy.models.v0041_openapi_reservation_resp_reservations_inner_watts import (
    V0041OpenapiReservationRespReservationsInnerWatts,
)
from slurmrestpy.models.v0041_openapi_resp import V0041OpenapiResp
from slurmrestpy.models.v0041_openapi_shares_resp import V0041OpenapiSharesResp
from slurmrestpy.models.v0041_openapi_shares_resp_shares import (
    V0041OpenapiSharesRespShares,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner import (
    V0041OpenapiSharesRespSharesSharesInner,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_shares import (
    V0041OpenapiSharesRespSharesSharesInnerShares,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_shares_normalized import (
    V0041OpenapiSharesRespSharesSharesInnerSharesNormalized,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_tres import (
    V0041OpenapiSharesRespSharesSharesInnerTres,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner import (
    V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInner,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_tres_run_seconds_inner_value import (
    V0041OpenapiSharesRespSharesSharesInnerTresRunSecondsInnerValue,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_tres_usage_inner import (
    V0041OpenapiSharesRespSharesSharesInnerTresUsageInner,
)
from slurmrestpy.models.v0041_openapi_shares_resp_shares_shares_inner_usage_normalized import (
    V0041OpenapiSharesRespSharesSharesInnerUsageNormalized,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp import (
    V0041OpenapiSlurmdbdConfigResp,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_accounts_inner import (
    V0041OpenapiSlurmdbdConfigRespAccountsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_accounts_inner_associations_inner import (
    V0041OpenapiSlurmdbdConfigRespAccountsInnerAssociationsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_accounts_inner_coordinators_inner import (
    V0041OpenapiSlurmdbdConfigRespAccountsInnerCoordinatorsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMax,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobs,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_accruing import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsAccruing,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_active import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsActive,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_per_submitted import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsPerSubmitted,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_jobs_total import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxJobsTotal,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_per import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_per_account import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxPerAccount,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_tres import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTres,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_tres_group import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresGroup,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutes,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_tres_minutes_per import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresMinutesPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_max_tres_per import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMaxTresPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_min import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerMin,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_associations_inner_priority import (
    V0041OpenapiSlurmdbdConfigRespAssociationsInnerPriority,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_clusters_inner import (
    V0041OpenapiSlurmdbdConfigRespClustersInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_clusters_inner_associations import (
    V0041OpenapiSlurmdbdConfigRespClustersInnerAssociations,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_clusters_inner_associations_root import (
    V0041OpenapiSlurmdbdConfigRespClustersInnerAssociationsRoot,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_instances_inner import (
    V0041OpenapiSlurmdbdConfigRespInstancesInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner import (
    V0041OpenapiSlurmdbdConfigRespQosInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimits,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_factor import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsFactor,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMax,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruing,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing_per_account import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerAccount,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_accruing_per_user import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxAccruingPerUser,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobs,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_accruing import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsAccruing,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_active_jobs_count import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxActiveJobsCount,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobs,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_active_jobs import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobs,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_active_jobs_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_active_jobs_per_account import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerAccount,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_active_jobs_per_user import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsActiveJobsPerUser,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_per_account import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerAccount,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_jobs_per_user import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxJobsPerUser,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTres,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutes,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_minutes_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresMinutesPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_tres_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxTresPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClock,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_job import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerJob,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_max_wall_clock_per_qos import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMaxWallClockPerQos,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_min import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMin,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_min_priority_threshold import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinPriorityThreshold,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTres,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_limits_min_tres_per import (
    V0041OpenapiSlurmdbdConfigRespQosInnerLimitsMinTresPer,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_preempt import (
    V0041OpenapiSlurmdbdConfigRespQosInnerPreempt,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_preempt_exempt_time import (
    V0041OpenapiSlurmdbdConfigRespQosInnerPreemptExemptTime,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_priority import (
    V0041OpenapiSlurmdbdConfigRespQosInnerPriority,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_usage_factor import (
    V0041OpenapiSlurmdbdConfigRespQosInnerUsageFactor,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_qos_inner_usage_threshold import (
    V0041OpenapiSlurmdbdConfigRespQosInnerUsageThreshold,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_config_resp_users_inner_wckeys_inner_accounting_inner_tres import (
    V0041OpenapiSlurmdbdConfigRespUsersInnerWckeysInnerAccountingInnerTRES,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp import (
    V0041OpenapiSlurmdbdJobsResp,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_errors_inner import (
    V0041OpenapiSlurmdbdJobsRespErrorsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner import (
    V0041OpenapiSlurmdbdJobsRespJobsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_array import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerArray,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_array_task_id import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerArrayTaskId,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_association import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerAssociation,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCode,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal_id import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignalId,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_exit_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerExitCode,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_het import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerHet,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_het_job_offset import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerHetJobOffset,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_priority import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerPriority,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_required import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerRequired,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_cpu import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerCpu,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_required_memory_per_node import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerRequiredMemoryPerNode,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_state import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerState,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPU,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequency,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency_max import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMax,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_cpu_requested_frequency_min import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerCPURequestedFrequencyMin,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_nodes import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerNodes,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatistics,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergy,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_statistics_energy_consumed import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerStatisticsEnergyConsumed,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_time import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTime,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_time_end import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeEnd,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_time_start import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTimeStart,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTres,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_consumed import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresConsumed,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequested,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_steps_inner_tres_requested_max_inner import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerStepsInnerTresRequestedMaxInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_time import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTime,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_tres import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTres,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_wckey import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerWckey,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_meta import (
    V0041OpenapiSlurmdbdJobsRespMeta,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_warnings_inner import (
    V0041OpenapiSlurmdbdJobsRespWarningsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_qos_removed_resp import (
    V0041OpenapiSlurmdbdQosRemovedResp,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_qos_resp import (
    V0041OpenapiSlurmdbdQosResp,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp import (
    V0041OpenapiSlurmdbdStatsResp,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics import (
    V0041OpenapiSlurmdbdStatsRespStatistics,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_rpcs_inner import (
    V0041OpenapiSlurmdbdStatsRespStatisticsRPCsInner,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_rollups import (
    V0041OpenapiSlurmdbdStatsRespStatisticsRollups,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_stats_resp_statistics_users_inner import (
    V0041OpenapiSlurmdbdStatsRespStatisticsUsersInner,
)
from slurmrestpy.models.v0041_openapi_tres_resp import V0041OpenapiTresResp
from slurmrestpy.models.v0041_openapi_users_add_cond_resp import (
    V0041OpenapiUsersAddCondResp,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition import (
    V0041OpenapiUsersAddCondRespAssociationCondition,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociation,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_grpjobs import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobs,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_grpjobsaccrue import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpjobsaccrue,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_grpsubmitjobs import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpsubmitjobs,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_grpwall import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationGrpwall,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_maxjobs import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobs,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_maxjobsaccrue import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxjobsaccrue,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_maxsubmitjobs import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxsubmitjobs,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_maxwalldurationperjob import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationMaxwalldurationperjob,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_association_condition_association_minpriothresh import (
    V0041OpenapiUsersAddCondRespAssociationConditionAssociationMinpriothresh,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_str import (
    V0041OpenapiUsersAddCondRespStr,
)
from slurmrestpy.models.v0041_openapi_users_add_cond_resp_user import (
    V0041OpenapiUsersAddCondRespUser,
)
from slurmrestpy.models.v0041_openapi_users_resp import V0041OpenapiUsersResp
from slurmrestpy.models.v0041_openapi_wckey_removed_resp import (
    V0041OpenapiWckeyRemovedResp,
)
from slurmrestpy.models.v0041_openapi_wckey_resp import V0041OpenapiWckeyResp
from slurmrestpy.models.v0041_update_node_msg import V0041UpdateNodeMsg
from slurmrestpy.models.v0041_update_node_msg_resume_after import (
    V0041UpdateNodeMsgResumeAfter,
)
from slurmrestpy.models.v0041_update_node_msg_weight import V0041UpdateNodeMsgWeight
from slurmrestpy.models.v0042_account import V0042Account
from slurmrestpy.models.v0042_account_short import V0042AccountShort
from slurmrestpy.models.v0042_accounting import V0042Accounting
from slurmrestpy.models.v0042_accounting_allocated import V0042AccountingAllocated
from slurmrestpy.models.v0042_accounts_add_cond import V0042AccountsAddCond
from slurmrestpy.models.v0042_acct_gather_energy import V0042AcctGatherEnergy
from slurmrestpy.models.v0042_assoc import V0042Assoc
from slurmrestpy.models.v0042_assoc_default import V0042AssocDefault
from slurmrestpy.models.v0042_assoc_max import V0042AssocMax
from slurmrestpy.models.v0042_assoc_max_jobs import V0042AssocMaxJobs
from slurmrestpy.models.v0042_assoc_max_jobs_per import V0042AssocMaxJobsPer
from slurmrestpy.models.v0042_assoc_max_per import V0042AssocMaxPer
from slurmrestpy.models.v0042_assoc_max_per_account import V0042AssocMaxPerAccount
from slurmrestpy.models.v0042_assoc_max_tres import V0042AssocMaxTres
from slurmrestpy.models.v0042_assoc_max_tres_group import V0042AssocMaxTresGroup
from slurmrestpy.models.v0042_assoc_max_tres_minutes import V0042AssocMaxTresMinutes
from slurmrestpy.models.v0042_assoc_max_tres_per import V0042AssocMaxTresPer
from slurmrestpy.models.v0042_assoc_min import V0042AssocMin
from slurmrestpy.models.v0042_assoc_rec_set import V0042AssocRecSet
from slurmrestpy.models.v0042_assoc_shares_obj_wrap import V0042AssocSharesObjWrap
from slurmrestpy.models.v0042_assoc_shares_obj_wrap_fairshare import (
    V0042AssocSharesObjWrapFairshare,
)
from slurmrestpy.models.v0042_assoc_shares_obj_wrap_tres import (
    V0042AssocSharesObjWrapTres,
)
from slurmrestpy.models.v0042_assoc_short import V0042AssocShort
from slurmrestpy.models.v0042_bf_exit_fields import V0042BfExitFields
from slurmrestpy.models.v0042_cluster_rec import V0042ClusterRec
from slurmrestpy.models.v0042_cluster_rec_associations import (
    V0042ClusterRecAssociations,
)
from slurmrestpy.models.v0042_cluster_rec_controller import V0042ClusterRecController
from slurmrestpy.models.v0042_controller_ping import V0042ControllerPing
from slurmrestpy.models.v0042_coord import V0042Coord
from slurmrestpy.models.v0042_cron_entry import V0042CronEntry
from slurmrestpy.models.v0042_cron_entry_line import V0042CronEntryLine
from slurmrestpy.models.v0042_float64_no_val_struct import V0042Float64NoValStruct
from slurmrestpy.models.v0042_instance import V0042Instance
from slurmrestpy.models.v0042_instance_time import V0042InstanceTime
from slurmrestpy.models.v0042_job import V0042Job
from slurmrestpy.models.v0042_job_alloc_req import V0042JobAllocReq
from slurmrestpy.models.v0042_job_array import V0042JobArray
from slurmrestpy.models.v0042_job_array_limits import V0042JobArrayLimits
from slurmrestpy.models.v0042_job_array_limits_max import V0042JobArrayLimitsMax
from slurmrestpy.models.v0042_job_array_limits_max_running import (
    V0042JobArrayLimitsMaxRunning,
)
from slurmrestpy.models.v0042_job_array_response_msg_entry import (
    V0042JobArrayResponseMsgEntry,
)
from slurmrestpy.models.v0042_job_comment import V0042JobComment
from slurmrestpy.models.v0042_job_desc_msg import V0042JobDescMsg
from slurmrestpy.models.v0042_job_desc_msg_rlimits import V0042JobDescMsgRlimits
from slurmrestpy.models.v0042_job_het import V0042JobHet
from slurmrestpy.models.v0042_job_info import V0042JobInfo
from slurmrestpy.models.v0042_job_info_power import V0042JobInfoPower
from slurmrestpy.models.v0042_job_mcs import V0042JobMcs
from slurmrestpy.models.v0042_job_required import V0042JobRequired
from slurmrestpy.models.v0042_job_res import V0042JobRes
from slurmrestpy.models.v0042_job_res_core import V0042JobResCore
from slurmrestpy.models.v0042_job_res_node import V0042JobResNode
from slurmrestpy.models.v0042_job_res_node_cpus import V0042JobResNodeCpus
from slurmrestpy.models.v0042_job_res_node_memory import V0042JobResNodeMemory
from slurmrestpy.models.v0042_job_res_nodes import V0042JobResNodes
from slurmrestpy.models.v0042_job_res_socket import V0042JobResSocket
from slurmrestpy.models.v0042_job_reservation import V0042JobReservation
from slurmrestpy.models.v0042_job_state import V0042JobState
from slurmrestpy.models.v0042_job_submit_req import V0042JobSubmitReq
from slurmrestpy.models.v0042_job_time import V0042JobTime
from slurmrestpy.models.v0042_job_time_system import V0042JobTimeSystem
from slurmrestpy.models.v0042_job_time_total import V0042JobTimeTotal
from slurmrestpy.models.v0042_job_time_user import V0042JobTimeUser
from slurmrestpy.models.v0042_job_tres import V0042JobTres
from slurmrestpy.models.v0042_kill_jobs_msg import V0042KillJobsMsg
from slurmrestpy.models.v0042_kill_jobs_resp_job import V0042KillJobsRespJob
from slurmrestpy.models.v0042_kill_jobs_resp_job_error import V0042KillJobsRespJobError
from slurmrestpy.models.v0042_kill_jobs_resp_job_federation import (
    V0042KillJobsRespJobFederation,
)
from slurmrestpy.models.v0042_license import V0042License
from slurmrestpy.models.v0042_node import V0042Node
from slurmrestpy.models.v0042_openapi_accounts_add_cond_resp import (
    V0042OpenapiAccountsAddCondResp,
)
from slurmrestpy.models.v0042_openapi_accounts_add_cond_resp_str import (
    V0042OpenapiAccountsAddCondRespStr,
)
from slurmrestpy.models.v0042_openapi_accounts_removed_resp import (
    V0042OpenapiAccountsRemovedResp,
)
from slurmrestpy.models.v0042_openapi_accounts_resp import V0042OpenapiAccountsResp
from slurmrestpy.models.v0042_openapi_assocs_removed_resp import (
    V0042OpenapiAssocsRemovedResp,
)
from slurmrestpy.models.v0042_openapi_assocs_resp import V0042OpenapiAssocsResp
from slurmrestpy.models.v0042_openapi_clusters_removed_resp import (
    V0042OpenapiClustersRemovedResp,
)
from slurmrestpy.models.v0042_openapi_clusters_resp import V0042OpenapiClustersResp
from slurmrestpy.models.v0042_openapi_diag_resp import V0042OpenapiDiagResp
from slurmrestpy.models.v0042_openapi_error import V0042OpenapiError
from slurmrestpy.models.v0042_openapi_instances_resp import V0042OpenapiInstancesResp
from slurmrestpy.models.v0042_openapi_job_alloc_resp import V0042OpenapiJobAllocResp
from slurmrestpy.models.v0042_openapi_job_info_resp import V0042OpenapiJobInfoResp
from slurmrestpy.models.v0042_openapi_job_post_response import (
    V0042OpenapiJobPostResponse,
)
from slurmrestpy.models.v0042_openapi_job_submit_response import (
    V0042OpenapiJobSubmitResponse,
)
from slurmrestpy.models.v0042_openapi_kill_job_resp import V0042OpenapiKillJobResp
from slurmrestpy.models.v0042_openapi_kill_jobs_resp import V0042OpenapiKillJobsResp
from slurmrestpy.models.v0042_openapi_licenses_resp import V0042OpenapiLicensesResp
from slurmrestpy.models.v0042_openapi_meta import V0042OpenapiMeta
from slurmrestpy.models.v0042_openapi_meta_client import V0042OpenapiMetaClient
from slurmrestpy.models.v0042_openapi_meta_plugin import V0042OpenapiMetaPlugin
from slurmrestpy.models.v0042_openapi_meta_slurm import V0042OpenapiMetaSlurm
from slurmrestpy.models.v0042_openapi_meta_slurm_version import (
    V0042OpenapiMetaSlurmVersion,
)
from slurmrestpy.models.v0042_openapi_nodes_resp import V0042OpenapiNodesResp
from slurmrestpy.models.v0042_openapi_partition_resp import V0042OpenapiPartitionResp
from slurmrestpy.models.v0042_openapi_ping_array_resp import V0042OpenapiPingArrayResp
from slurmrestpy.models.v0042_openapi_reservation_resp import (
    V0042OpenapiReservationResp,
)
from slurmrestpy.models.v0042_openapi_resp import V0042OpenapiResp
from slurmrestpy.models.v0042_openapi_shares_resp import V0042OpenapiSharesResp
from slurmrestpy.models.v0042_openapi_slurmdbd_config_resp import (
    V0042OpenapiSlurmdbdConfigResp,
)
from slurmrestpy.models.v0042_openapi_slurmdbd_jobs_resp import (
    V0042OpenapiSlurmdbdJobsResp,
)
from slurmrestpy.models.v0042_openapi_slurmdbd_ping_resp import (
    V0042OpenapiSlurmdbdPingResp,
)
from slurmrestpy.models.v0042_openapi_slurmdbd_qos_removed_resp import (
    V0042OpenapiSlurmdbdQosRemovedResp,
)
from slurmrestpy.models.v0042_openapi_slurmdbd_qos_resp import (
    V0042OpenapiSlurmdbdQosResp,
)
from slurmrestpy.models.v0042_openapi_slurmdbd_stats_resp import (
    V0042OpenapiSlurmdbdStatsResp,
)
from slurmrestpy.models.v0042_openapi_tres_resp import V0042OpenapiTresResp
from slurmrestpy.models.v0042_openapi_users_add_cond_resp import (
    V0042OpenapiUsersAddCondResp,
)
from slurmrestpy.models.v0042_openapi_users_add_cond_resp_str import (
    V0042OpenapiUsersAddCondRespStr,
)
from slurmrestpy.models.v0042_openapi_users_resp import V0042OpenapiUsersResp
from slurmrestpy.models.v0042_openapi_warning import V0042OpenapiWarning
from slurmrestpy.models.v0042_openapi_wckey_removed_resp import (
    V0042OpenapiWckeyRemovedResp,
)
from slurmrestpy.models.v0042_openapi_wckey_resp import V0042OpenapiWckeyResp
from slurmrestpy.models.v0042_part_prio import V0042PartPrio
from slurmrestpy.models.v0042_partition_info import V0042PartitionInfo
from slurmrestpy.models.v0042_partition_info_accounts import V0042PartitionInfoAccounts
from slurmrestpy.models.v0042_partition_info_cpus import V0042PartitionInfoCpus
from slurmrestpy.models.v0042_partition_info_defaults import V0042PartitionInfoDefaults
from slurmrestpy.models.v0042_partition_info_groups import V0042PartitionInfoGroups
from slurmrestpy.models.v0042_partition_info_maximums import V0042PartitionInfoMaximums
from slurmrestpy.models.v0042_partition_info_maximums_oversubscribe import (
    V0042PartitionInfoMaximumsOversubscribe,
)
from slurmrestpy.models.v0042_partition_info_minimums import V0042PartitionInfoMinimums
from slurmrestpy.models.v0042_partition_info_nodes import V0042PartitionInfoNodes
from slurmrestpy.models.v0042_partition_info_partition import (
    V0042PartitionInfoPartition,
)
from slurmrestpy.models.v0042_partition_info_priority import V0042PartitionInfoPriority
from slurmrestpy.models.v0042_partition_info_qos import V0042PartitionInfoQos
from slurmrestpy.models.v0042_partition_info_timeouts import V0042PartitionInfoTimeouts
from slurmrestpy.models.v0042_partition_info_tres import V0042PartitionInfoTres
from slurmrestpy.models.v0042_process_exit_code_verbose import (
    V0042ProcessExitCodeVerbose,
)
from slurmrestpy.models.v0042_process_exit_code_verbose_signal import (
    V0042ProcessExitCodeVerboseSignal,
)
from slurmrestpy.models.v0042_qos import V0042Qos
from slurmrestpy.models.v0042_qos_limits import V0042QosLimits
from slurmrestpy.models.v0042_qos_limits_max import V0042QosLimitsMax
from slurmrestpy.models.v0042_qos_limits_max_active_jobs import (
    V0042QosLimitsMaxActiveJobs,
)
from slurmrestpy.models.v0042_qos_limits_max_jobs import V0042QosLimitsMaxJobs
from slurmrestpy.models.v0042_qos_limits_max_jobs_active_jobs import (
    V0042QosLimitsMaxJobsActiveJobs,
)
from slurmrestpy.models.v0042_qos_limits_max_jobs_active_jobs_per import (
    V0042QosLimitsMaxJobsActiveJobsPer,
)
from slurmrestpy.models.v0042_qos_limits_max_tres import V0042QosLimitsMaxTres
from slurmrestpy.models.v0042_qos_limits_max_tres_minutes import (
    V0042QosLimitsMaxTresMinutes,
)
from slurmrestpy.models.v0042_qos_limits_max_tres_minutes_per import (
    V0042QosLimitsMaxTresMinutesPer,
)
from slurmrestpy.models.v0042_qos_limits_max_tres_per import V0042QosLimitsMaxTresPer
from slurmrestpy.models.v0042_qos_limits_max_wall_clock import (
    V0042QosLimitsMaxWallClock,
)
from slurmrestpy.models.v0042_qos_limits_max_wall_clock_per import (
    V0042QosLimitsMaxWallClockPer,
)
from slurmrestpy.models.v0042_qos_limits_min import V0042QosLimitsMin
from slurmrestpy.models.v0042_qos_limits_min_tres import V0042QosLimitsMinTres
from slurmrestpy.models.v0042_qos_limits_min_tres_per import V0042QosLimitsMinTresPer
from slurmrestpy.models.v0042_qos_preempt import V0042QosPreempt
from slurmrestpy.models.v0042_reservation_core_spec import V0042ReservationCoreSpec
from slurmrestpy.models.v0042_reservation_info import V0042ReservationInfo
from slurmrestpy.models.v0042_reservation_info_purge_completed import (
    V0042ReservationInfoPurgeCompleted,
)
from slurmrestpy.models.v0042_rollup_stats import V0042RollupStats
from slurmrestpy.models.v0042_rollup_stats_daily import V0042RollupStatsDaily
from slurmrestpy.models.v0042_rollup_stats_daily_duration import (
    V0042RollupStatsDailyDuration,
)
from slurmrestpy.models.v0042_rollup_stats_hourly import V0042RollupStatsHourly
from slurmrestpy.models.v0042_rollup_stats_hourly_duration import (
    V0042RollupStatsHourlyDuration,
)
from slurmrestpy.models.v0042_rollup_stats_monthly import V0042RollupStatsMonthly
from slurmrestpy.models.v0042_rollup_stats_monthly_duration import (
    V0042RollupStatsMonthlyDuration,
)
from slurmrestpy.models.v0042_schedule_exit_fields import V0042ScheduleExitFields
from slurmrestpy.models.v0042_shares_float128_tres import V0042SharesFloat128Tres
from slurmrestpy.models.v0042_shares_resp_msg import V0042SharesRespMsg
from slurmrestpy.models.v0042_shares_uint64_tres import V0042SharesUint64Tres
from slurmrestpy.models.v0042_slurmdbd_ping import V0042SlurmdbdPing
from slurmrestpy.models.v0042_stats_msg import V0042StatsMsg
from slurmrestpy.models.v0042_stats_msg_rpc_dump import V0042StatsMsgRpcDump
from slurmrestpy.models.v0042_stats_msg_rpc_queue import V0042StatsMsgRpcQueue
from slurmrestpy.models.v0042_stats_msg_rpc_type import V0042StatsMsgRpcType
from slurmrestpy.models.v0042_stats_msg_rpc_user import V0042StatsMsgRpcUser
from slurmrestpy.models.v0042_stats_rec import V0042StatsRec
from slurmrestpy.models.v0042_stats_rpc import V0042StatsRpc
from slurmrestpy.models.v0042_stats_rpc_time import V0042StatsRpcTime
from slurmrestpy.models.v0042_stats_user import V0042StatsUser
from slurmrestpy.models.v0042_step import V0042Step
from slurmrestpy.models.v0042_step_cpu import V0042StepCPU
from slurmrestpy.models.v0042_step_cpu_requested_frequency import (
    V0042StepCPURequestedFrequency,
)
from slurmrestpy.models.v0042_step_nodes import V0042StepNodes
from slurmrestpy.models.v0042_step_statistics import V0042StepStatistics
from slurmrestpy.models.v0042_step_statistics_cpu import V0042StepStatisticsCPU
from slurmrestpy.models.v0042_step_statistics_energy import V0042StepStatisticsEnergy
from slurmrestpy.models.v0042_step_step import V0042StepStep
from slurmrestpy.models.v0042_step_task import V0042StepTask
from slurmrestpy.models.v0042_step_tasks import V0042StepTasks
from slurmrestpy.models.v0042_step_time import V0042StepTime
from slurmrestpy.models.v0042_step_time_system import V0042StepTimeSystem
from slurmrestpy.models.v0042_step_time_total import V0042StepTimeTotal
from slurmrestpy.models.v0042_step_time_user import V0042StepTimeUser
from slurmrestpy.models.v0042_step_tres import V0042StepTres
from slurmrestpy.models.v0042_step_tres_consumed import V0042StepTresConsumed
from slurmrestpy.models.v0042_step_tres_requested import V0042StepTresRequested
from slurmrestpy.models.v0042_tres import V0042Tres
from slurmrestpy.models.v0042_uint16_no_val_struct import V0042Uint16NoValStruct
from slurmrestpy.models.v0042_uint32_no_val_struct import V0042Uint32NoValStruct
from slurmrestpy.models.v0042_uint64_no_val_struct import V0042Uint64NoValStruct
from slurmrestpy.models.v0042_update_node_msg import V0042UpdateNodeMsg
from slurmrestpy.models.v0042_user import V0042User
from slurmrestpy.models.v0042_user_default import V0042UserDefault
from slurmrestpy.models.v0042_user_short import V0042UserShort
from slurmrestpy.models.v0042_users_add_cond import V0042UsersAddCond
from slurmrestpy.models.v0042_wckey import V0042Wckey
from slurmrestpy.models.v0042_wckey_tag_struct import V0042WckeyTagStruct



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_assoc import V0042Assoc


class TestV0042Assoc(unittest.TestCase):
    """V0042Assoc unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042Assoc:
        """Test V0042Assoc
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042Assoc`
        """
        model = V0042Assoc()
        if include_optional:
            return V0042Assoc(
                accounting = [
                    slurmrestpy.models.v0/0/42_accounting.v0.0.42_accounting(
                        allocated = slurmrestpy.models.v0_0_42_accounting_allocated.v0_0_42_accounting_allocated(
                            seconds = 56, ),
                        id = 56,
                        id_alt = 56,
                        start = 56,
                        tres = slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                            type = '',
                            name = '',
                            id = 56,
                            count = 56, ), )
                    ],
                account = '',
                cluster = '',
                comment = '',
                default = slurmrestpy.models.v0_0_42_assoc_default.v0_0_42_assoc_default(
                    qos = '', ),
                flags = [
                    'DELETED'
                    ],
                max = slurmrestpy.models.v0_0_42_assoc_max.v0_0_42_assoc_max(
                    jobs = slurmrestpy.models.v0_0_42_assoc_max_jobs.v0_0_42_assoc_max_jobs(
                        per = slurmrestpy.models.v0_0_42_assoc_max_jobs_per.v0_0_42_assoc_max_jobs_per(
                            count = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            accruing = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                set = True,
                                infinite = True,
                                number = 56, ),
                            submitted = ,
                            wall_clock = , ),
                        active = ,
                        accruing = ,
                        total = , ),
                    tres = slurmrestpy.models.v0_0_42_assoc_max_tres.v0_0_42_assoc_max_tres(
                        group = slurmrestpy.models.v0_0_42_assoc_max_tres_group.v0_0_42_assoc_max_tres_group(
                            minutes = [
                                slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                    type = '',
                                    name = '',
                                    id = 56, )
                                ], ),
                        minutes = slurmrestpy.models.v0_0_42_assoc_max_tres_minutes.v0_0_42_assoc_max_tres_minutes(), ),
                    per = slurmrestpy.models.v0_0_42_assoc_max_per.v0_0_42_assoc_max_per(
                        account = slurmrestpy.models.v0_0_42_assoc_max_per_account.v0_0_42_assoc_max_per_account(), ), ),
                id = 56,
                is_default = True,
                lineage = '',
                min = slurmrestpy.models.v0_0_42_assoc_min.v0_0_42_assoc_min(
                    priority_threshold = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                        set = True,
                        infinite = True,
                        number = 56, ), ),
                parent_account = '',
                partition = '',
                priority = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                    set = True,
                    infinite = True,
                    number = 56, ),
                qos = [
                    ''
                    ],
                shares_raw = 56,
                user = ''
            )
        else:
            return V0042Assoc(
                user = '',
        )
        """

    def testV0042Assoc(self):
        """Test V0042Assoc"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_return_code import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_derived_exit_code_signal import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal,
)


class V0041OpenapiJobInfoRespJobsInnerExitCode(BaseModel):
    """
    Exit code of the job
    """  # noqa: E501

    status: Optional[List[StrictStr]] = Field(
        default=None, description="Status given by return code"
    )
    return_code: Optional[
        V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode
    ] = None
    signal: Optional[V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal] = None
    __properties: ClassVar[List[str]] = ["status", "return_code", "signal"]

    @field_validator("status")
    def status_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                ["INVALID", "PENDING", "SUCCESS", "ERROR", "SIGNALED", "CORE_DUMPED"]
            ):
                raise ValueError(
                    "each list item must be one of ('INVALID', 'PENDING', 'SUCCESS', 'ERROR', 'SIGNALED', 'CORE_DUMPED')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerExitCode from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of return_code
        if self.return_code:
            _dict["return_code"] = self.return_code.to_dict()
        # override the default output from pydantic by calling `to_dict()` of signal
        if self.signal:
            _dict["signal"] = self.signal.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiJobInfoRespJobsInnerExitCode from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "status": obj.get("status"),
                "return_code": V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeReturnCode.from_dict(
                    obj["return_code"]
                )
                if obj.get("return_code") is not None
                else None,
                "signal": V0041OpenapiSlurmdbdJobsRespJobsInnerDerivedExitCodeSignal.from_dict(
                    obj["signal"]
                )
                if obj.get("signal") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0041_openapi_kill_jobs_resp_status_inner import (
    V0041OpenapiKillJobsRespStatusInner,
)


class TestV0041OpenapiKillJobsRespStatusInner(unittest.TestCase):
    """V0041OpenapiKillJobsRespStatusInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0041OpenapiKillJobsRespStatusInner:
        """Test V0041OpenapiKillJobsRespStatusInner
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0041OpenapiKillJobsRespStatusInner`
        """
        model = V0041OpenapiKillJobsRespStatusInner()
        if include_optional:
            return V0041OpenapiKillJobsRespStatusInner(
                error = slurmrestpy.models.v0_0_42_kill_jobs_resp_job_error.v0_0_42_kill_jobs_resp_job_error(
                    string = '',
                    code = 56,
                    message = '', ),
                step_id = '',
                job_id = slurmrestpy.models.v0_0_41_openapi_kill_jobs_resp_status_inner_job_id.v0_0_41_openapi_kill_jobs_resp_status_inner_job_id(
                    set = True,
                    infinite = True,
                    number = 56, ),
                federation = slurmrestpy.models.v0_0_42_kill_jobs_resp_job_federation.v0_0_42_kill_jobs_resp_job_federation(
                    sibling = '', )
            )
        else:
            return V0041OpenapiKillJobsRespStatusInner(
                step_id = '',
                job_id = slurmrestpy.models.v0_0_41_openapi_kill_jobs_resp_status_inner_job_id.v0_0_41_openapi_kill_jobs_resp_status_inner_job_id(
                    set = True,
                    infinite = True,
                    number = 56, ),
        )
        """

    def testV0041OpenapiKillJobsRespStatusInner(self):
        """Test V0041OpenapiKillJobsRespStatusInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

import unittest

from slurmrestpy.models.v0042_openapi_slurmdbd_config_resp import (
    V0042OpenapiSlurmdbdConfigResp,
)


class TestV0042OpenapiSlurmdbdConfigResp(unittest.TestCase):
    """V0042OpenapiSlurmdbdConfigResp unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> V0042OpenapiSlurmdbdConfigResp:
        """Test V0042OpenapiSlurmdbdConfigResp
        include_optional is a boolean, when False only required
        params are included, when True both required and
        optional params are included"""
        # uncomment below to create an instance of `V0042OpenapiSlurmdbdConfigResp`
        """
        model = V0042OpenapiSlurmdbdConfigResp()
        if include_optional:
            return V0042OpenapiSlurmdbdConfigResp(
                clusters = [
                    slurmrestpy.models.v0/0/42_cluster_rec.v0.0.42_cluster_rec(
                        controller = slurmrestpy.models.v0_0_42_cluster_rec_controller.v0_0_42_cluster_rec_controller(
                            host = '',
                            port = 56, ),
                        flags = [
                            'REGISTERING'
                            ],
                        name = '',
                        nodes = '',
                        select_plugin = '',
                        associations = slurmrestpy.models.v0_0_42_cluster_rec_associations.v0_0_42_cluster_rec_associations(
                            root = slurmrestpy.models.v0/0/42_assoc_short.v0.0.42_assoc_short(
                                account = '',
                                cluster = '',
                                partition = '',
                                user = '',
                                id = 56, ), ),
                        rpc_version = 56,
                        tres = [
                            slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                type = '',
                                name = '',
                                id = 56,
                                count = 56, )
                            ], )
                    ],
                tres = [
                    slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                        type = '',
                        name = '',
                        id = 56,
                        count = 56, )
                    ],
                accounts = [
                    slurmrestpy.models.v0/0/42_account.v0.0.42_account(
                        associations = [
                            slurmrestpy.models.v0/0/42_assoc_short.v0.0.42_assoc_short(
                                account = '',
                                cluster = '',
                                partition = '',
                                user = '',
                                id = 56, )
                            ],
                        coordinators = [
                            slurmrestpy.models.v0/0/42_coord.v0.0.42_coord(
                                name = '',
                                direct = True, )
                            ],
                        description = '',
                        name = '',
                        organization = '',
                        flags = [
                            'DELETED'
                            ], )
                    ],
                users = [
                    slurmrestpy.models.v0/0/42_user.v0.0.42_user(
                        administrator_level = [
                            'Not Set'
                            ],
                        associations = [
                            slurmrestpy.models.v0/0/42_assoc_short.v0.0.42_assoc_short(
                                account = '',
                                cluster = '',
                                partition = '',
                                user = '',
                                id = 56, )
                            ],
                        coordinators = [
                            slurmrestpy.models.v0/0/42_coord.v0.0.42_coord(
                                name = '',
                                direct = True, )
                            ],
                        default = slurmrestpy.models.v0_0_42_user_default.v0_0_42_user_default(
                            account = '',
                            wckey = '', ),
                        flags = [
                            'NONE'
                            ],
                        name = '',
                        old_name = '',
                        wckeys = [
                            slurmrestpy.models.v0/0/42_wckey.v0.0.42_wckey(
                                accounting = [
                                    slurmrestpy.models.v0/0/42_accounting.v0.0.42_accounting(
                                        allocated = slurmrestpy.models.v0_0_42_accounting_allocated.v0_0_42_accounting_allocated(
                                            seconds = 56, ),
                                        id = 56,
                                        id_alt = 56,
                                        start = 56,
                                        tres = slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                            type = '',
                                            name = '',
                                            id = 56,
                                            count = 56, ), )
                                    ],
                                cluster = '',
                                id = 56,
                                name = '',
                                user = '', )
                            ], )
                    ],
                qos = [
                    slurmrestpy.models.v0/0/42_qos.v0.0.42_qos(
                        description = '',
                        flags = [
                            'NOT_SET'
                            ],
                        id = 56,
                        limits = slurmrestpy.models.v0_0_42_qos_limits.v0_0_42_qos_limits(
                            grace_time = 56,
                            max = slurmrestpy.models.v0_0_42_qos_limits_max.v0_0_42_qos_limits_max(
                                active_jobs = slurmrestpy.models.v0_0_42_qos_limits_max_active_jobs.v0_0_42_qos_limits_max_active_jobs(
                                    accruing = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    count = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                        set = True,
                                        infinite = True,
                                        number = 56, ), ),
                                jobs = slurmrestpy.models.v0_0_42_qos_limits_max_jobs.v0_0_42_qos_limits_max_jobs(
                                    per = slurmrestpy.models.v0_0_42_qos_limits_max_jobs_active_jobs_per.v0_0_42_qos_limits_max_jobs_active_jobs_per(
                                        account = ,
                                        user = , ), ),
                                tres = slurmrestpy.models.v0_0_42_qos_limits_max_tres.v0_0_42_qos_limits_max_tres(
                                    total = [
                                        slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ],
                                    minutes = slurmrestpy.models.v0_0_42_qos_limits_max_tres_minutes.v0_0_42_qos_limits_max_tres_minutes(), ),
                                wall_clock = slurmrestpy.models.v0_0_42_qos_limits_max_wall_clock.v0_0_42_qos_limits_max_wall_clock(),
                                accruing = slurmrestpy.models.v0_0_42_qos_limits_max_jobs_active_jobs.v0_0_42_qos_limits_max_jobs_active_jobs(), ),
                            factor = slurmrestpy.models.v0/0/42_float64_no_val_struct.v0.0.42_float64_no_val_struct(
                                set = True,
                                infinite = True,
                                number = 1.337, ),
                            min = slurmrestpy.models.v0_0_42_qos_limits_min.v0_0_42_qos_limits_min(
                                priority_threshold = , ), ),
                        name = '',
                        preempt = slurmrestpy.models.v0_0_42_qos_preempt.v0_0_42_qos_preempt(
                            list = [
                                ''
                                ],
                            mode = [
                                'DISABLED'
                                ],
                            exempt_time = , ),
                        priority = ,
                        usage_factor = slurmrestpy.models.v0/0/42_float64_no_val_struct.v0.0.42_float64_no_val_struct(
                            set = True,
                            infinite = True,
                            number = 1.337, ),
                        usage_threshold = , )
                    ],
                wckeys = [
                    slurmrestpy.models.v0/0/42_wckey.v0.0.42_wckey(
                        accounting = [
                            slurmrestpy.models.v0/0/42_accounting.v0.0.42_accounting(
                                allocated = slurmrestpy.models.v0_0_42_accounting_allocated.v0_0_42_accounting_allocated(
                                    seconds = 56, ),
                                id = 56,
                                id_alt = 56,
                                start = 56,
                                tres = slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, ), )
                            ],
                        cluster = '',
                        id = 56,
                        name = '',
                        user = '',
                        flags = [
                            'DELETED'
                            ], )
                    ],
                associations = [
                    slurmrestpy.models.v0/0/42_assoc.v0.0.42_assoc(
                        accounting = [
                            slurmrestpy.models.v0/0/42_accounting.v0.0.42_accounting(
                                allocated = slurmrestpy.models.v0_0_42_accounting_allocated.v0_0_42_accounting_allocated(
                                    seconds = 56, ),
                                id = 56,
                                id_alt = 56,
                                start = 56,
                                tres = slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                    type = '',
                                    name = '',
                                    id = 56,
                                    count = 56, ), )
                            ],
                        account = '',
                        cluster = '',
                        comment = '',
                        default = slurmrestpy.models.v0_0_42_assoc_default.v0_0_42_assoc_default(
                            qos = '', ),
                        flags = [
                            'DELETED'
                            ],
                        max = slurmrestpy.models.v0_0_42_assoc_max.v0_0_42_assoc_max(
                            jobs = slurmrestpy.models.v0_0_42_assoc_max_jobs.v0_0_42_assoc_max_jobs(
                                per = slurmrestpy.models.v0_0_42_assoc_max_jobs_per.v0_0_42_assoc_max_jobs_per(
                                    count = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    accruing = slurmrestpy.models.v0/0/42_uint32_no_val_struct.v0.0.42_uint32_no_val_struct(
                                        set = True,
                                        infinite = True,
                                        number = 56, ),
                                    submitted = ,
                                    wall_clock = , ),
                                active = ,
                                accruing = ,
                                total = , ),
                            tres = slurmrestpy.models.v0_0_42_assoc_max_tres.v0_0_42_assoc_max_tres(
                                group = slurmrestpy.models.v0_0_42_assoc_max_tres_group.v0_0_42_assoc_max_tres_group(
                                    minutes = [
                                        slurmrestpy.models.v0/0/42_tres.v0.0.42_tres(
                                            type = '',
                                            name = '',
                                            id = 56, )
                                        ], ),
                                minutes = slurmrestpy.models.v0_0_42_assoc_max_tres_minutes.v0_0_42_assoc_max_tres_minutes(), ),
                            per = slurmrestpy.models.v0_0_42_assoc_max_per.v0_0_42_assoc_max_per(
                                account = slurmrestpy.models.v0_0_42_assoc_max_per_account.v0_0_42_assoc_max_per_account(), ), ),
                        id = 56,
                        is_default = True,
                        lineage = '',
                        min = slurmrestpy.models.v0_0_42_assoc_min.v0_0_42_assoc_min(
                            priority_threshold = , ),
                        parent_account = '',
                        partition = '',
                        priority = ,
                        qos = [
                            ''
                            ],
                        shares_raw = 56,
                        user = '', )
                    ],
                instances = [
                    slurmrestpy.models.v0/0/42_instance.v0.0.42_instance(
                        cluster = '',
                        extra = '',
                        instance_id = '',
                        instance_type = '',
                        node_name = '',
                        time = slurmrestpy.models.v0_0_42_instance_time.v0_0_42_instance_time(
                            time_end = 56,
                            time_start = 56, ), )
                    ],
                meta = slurmrestpy.models.v0/0/42_openapi_meta.v0.0.42_openapi_meta(
                    plugin = slurmrestpy.models.v0_0_42_openapi_meta_plugin.v0_0_42_openapi_meta_plugin(
                        type = '',
                        name = '',
                        data_parser = '',
                        accounting_storage = '', ),
                    client = slurmrestpy.models.v0_0_42_openapi_meta_client.v0_0_42_openapi_meta_client(
                        source = '',
                        user = '',
                        group = '', ),
                    command = [
                        ''
                        ],
                    slurm = slurmrestpy.models.v0_0_42_openapi_meta_slurm.v0_0_42_openapi_meta_slurm(
                        version = slurmrestpy.models.v0_0_42_openapi_meta_slurm_version.v0_0_42_openapi_meta_slurm_version(
                            major = '',
                            micro = '',
                            minor = '', ),
                        release = '',
                        cluster = '', ), ),
                errors = [
                    slurmrestpy.models.v0/0/42_openapi_error.v0.0.42_openapi_error(
                        description = '',
                        error_number = 56,
                        error = '',
                        source = '', )
                    ],
                warnings = [
                    slurmrestpy.models.v0/0/42_openapi_warning.v0.0.42_openapi_warning(
                        description = '',
                        source = '', )
                    ]
            )
        else:
            return V0042OpenapiSlurmdbdConfigResp(
        )
        """

    def testV0042OpenapiSlurmdbdConfigResp(self):
        """Test V0042OpenapiSlurmdbdConfigResp"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == "__main__":
    unittest.main()



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing_extensions import Self

from slurmrestpy.models.v0042_cron_entry_line import V0042CronEntryLine


class V0041JobDescMsgCrontab(BaseModel):
    """
    Specification for scrontab job
    """  # noqa: E501

    flags: Optional[List[StrictStr]] = Field(default=None, description="Flags")
    minute: Optional[StrictStr] = Field(
        default=None,
        description="Ranged string specifying eligible minute values (e.g. 0-10,50)",
    )
    hour: Optional[StrictStr] = Field(
        default=None,
        description="Ranged string specifying eligible hour values (e.g. 0-5,23)",
    )
    day_of_month: Optional[StrictStr] = Field(
        default=None,
        description="Ranged string specifying eligible day of month values (e.g. 0-10,29)",
    )
    month: Optional[StrictStr] = Field(
        default=None,
        description="Ranged string specifying eligible month values (e.g. 0-5,12)",
    )
    day_of_week: Optional[StrictStr] = Field(
        default=None,
        description="Ranged string specifying eligible day of week values (e.g.0-3,7)",
    )
    specification: Optional[StrictStr] = Field(
        default=None,
        description="Time specification (* means valid for all allowed values) - minute hour day_of_month month day_of_week",
    )
    command: Optional[StrictStr] = Field(default=None, description="Command to run")
    line: Optional[V0042CronEntryLine] = None
    __properties: ClassVar[List[str]] = [
        "flags",
        "minute",
        "hour",
        "day_of_month",
        "month",
        "day_of_week",
        "specification",
        "command",
        "line",
    ]

    @field_validator("flags")
    def flags_validate_enum(cls, value):
        """Validates the enum"""
        if value is None:
            return value

        for i in value:
            if i not in set(
                [
                    "WILD_MINUTE",
                    "WILD_HOUR",
                    "WILD_DAY_OF_MONTH",
                    "WILD_MONTH",
                    "WILD_DAY_OF_WEEK",
                ]
            ):
                raise ValueError(
                    "each list item must be one of ('WILD_MINUTE', 'WILD_HOUR', 'WILD_DAY_OF_MONTH', 'WILD_MONTH', 'WILD_DAY_OF_WEEK')"
                )
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041JobDescMsgCrontab from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of line
        if self.line:
            _dict["line"] = self.line.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041JobDescMsgCrontab from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "flags": obj.get("flags"),
                "minute": obj.get("minute"),
                "hour": obj.get("hour"),
                "day_of_month": obj.get("day_of_month"),
                "month": obj.get("month"),
                "day_of_week": obj.get("day_of_week"),
                "specification": obj.get("specification"),
                "command": obj.get("command"),
                "line": V0042CronEntryLine.from_dict(obj["line"])
                if obj.get("line") is not None
                else None,
            }
        )
        return _obj



# coding: utf-8

"""
Slurm REST API

API to access and control Slurm

The version of the OpenAPI document: Slurm-24.11.1&openapi/slurmdbd&openapi/slurmctld
Contact: sales@schedmd.com
Generated by OpenAPI Generator (https://openapi-generator.tech)

Do not edit the class manually.
"""  # noqa: E501

from __future__ import annotations

import json
import pprint
import re  # noqa: F401
from typing import Any, ClassVar, Dict, List, Optional, Set

from pydantic import BaseModel, ConfigDict, Field, StrictInt
from typing_extensions import Self

from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_time_limit import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit,
)
from slurmrestpy.models.v0041_openapi_slurmdbd_jobs_resp_jobs_inner_time_planned import (
    V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned,
)
from slurmrestpy.models.v0042_job_time_system import V0042JobTimeSystem
from slurmrestpy.models.v0042_job_time_total import V0042JobTimeTotal
from slurmrestpy.models.v0042_job_time_user import V0042JobTimeUser


class V0041OpenapiSlurmdbdJobsRespJobsInnerTime(BaseModel):
    """
    V0041OpenapiSlurmdbdJobsRespJobsInnerTime
    """  # noqa: E501

    elapsed: Optional[StrictInt] = Field(
        default=None, description="Elapsed time in seconds"
    )
    eligible: Optional[StrictInt] = Field(
        default=None,
        description="Time when the job became eligible to run (UNIX timestamp)",
    )
    end: Optional[StrictInt] = Field(
        default=None, description="End time (UNIX timestamp)"
    )
    planned: Optional[V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned] = None
    start: Optional[StrictInt] = Field(
        default=None, description="Time execution began (UNIX timestamp)"
    )
    submission: Optional[StrictInt] = Field(
        default=None, description="Time when the job was submitted (UNIX timestamp)"
    )
    suspended: Optional[StrictInt] = Field(
        default=None, description="Total time in suspended state in seconds"
    )
    system: Optional[V0042JobTimeSystem] = None
    limit: Optional[V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit] = None
    total: Optional[V0042JobTimeTotal] = None
    user: Optional[V0042JobTimeUser] = None
    __properties: ClassVar[List[str]] = [
        "elapsed",
        "eligible",
        "end",
        "planned",
        "start",
        "submission",
        "suspended",
        "system",
        "limit",
        "total",
        "user",
    ]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdJobsRespJobsInnerTime from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of planned
        if self.planned:
            _dict["planned"] = self.planned.to_dict()
        # override the default output from pydantic by calling `to_dict()` of system
        if self.system:
            _dict["system"] = self.system.to_dict()
        # override the default output from pydantic by calling `to_dict()` of limit
        if self.limit:
            _dict["limit"] = self.limit.to_dict()
        # override the default output from pydantic by calling `to_dict()` of total
        if self.total:
            _dict["total"] = self.total.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict["user"] = self.user.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of V0041OpenapiSlurmdbdJobsRespJobsInnerTime from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate(
            {
                "elapsed": obj.get("elapsed"),
                "eligible": obj.get("eligible"),
                "end": obj.get("end"),
                "planned": V0041OpenapiSlurmdbdJobsRespJobsInnerTimePlanned.from_dict(
                    obj["planned"]
                )
                if obj.get("planned") is not None
                else None,
                "start": obj.get("start"),
                "submission": obj.get("submission"),
                "suspended": obj.get("suspended"),
                "system": V0042JobTimeSystem.from_dict(obj["system"])
                if obj.get("system") is not None
                else None,
                "limit": V0041OpenapiSlurmdbdJobsRespJobsInnerTimeLimit.from_dict(
                    obj["limit"]
                )
                if obj.get("limit") is not None
                else None,
                "total": V0042JobTimeTotal.from_dict(obj["total"])
                if obj.get("total") is not None
                else None,
                "user": V0042JobTimeUser.from_dict(obj["user"])
                if obj.get("user") is not None
                else None,
            }
        )
        return _obj
